@@ -1,13 +1,13 @@
 "dataquality"
 
-__version__ = "v0.0.9"
+__version__ = "v0.0.10"
 
 import resource
 
 import dataquality.core._config
 from dataquality.core._config import config
 from dataquality.core.auth import login
-from dataquality.core.finish import finish
+from dataquality.core.finish import finish, get_run_status, wait_for_run
 from dataquality.core.init import init
 from dataquality.core.log import (
     docs,
@@ -52,6 +52,8 @@ __all__ = [
     "get_model_logger",
     "set_tasks_for_run",
     "docs",
+    "wait_for_run",
+    "get_run_status",
 ]
 
 try:
