@@ -140,10 +140,12 @@ class TextClassificationDataLogger(BaseGalileoDataLogger):
         if os.path.isfile(file_path):
             new_name = f"{write_input_dir}/{str(uuid4()).replace('-', '')[:12]}.arrow"
             os.rename(file_path, new_name)
-            vaex.concat([df, vaex.open(new_name)]).export(file_path, progress="vaex")
+            with vaex.progress.tree("vaex", title="Appending input data"):
+                vaex.concat([df, vaex.open(new_name)]).export(file_path)
             os.remove(new_name)
         else:
-            df.export(file_path, progress="vaex")
+            with vaex.progress.tree("vaex", title="Exporting input data"):
+                df.export(file_path)
         df.close()
 
     def _get_input_dict(self) -> Dict[str, Any]:
@@ -157,7 +159,9 @@ class TextClassificationDataLogger(BaseGalileoDataLogger):
         )
 
     @classmethod
-    def split_dataframe(cls, df: DataFrame) -> Tuple[DataFrame, DataFrame, DataFrame]:
+    def split_dataframe(
+        cls, df: DataFrame, prob_only: bool
+    ) -> Tuple[DataFrame, DataFrame, DataFrame]:
         """Splits the singular dataframe into its 3 components
 
         Gets the probability df, the embedding df, and the "data" df containing
@@ -165,13 +169,26 @@ class TextClassificationDataLogger(BaseGalileoDataLogger):
         """
         df_copy = df.copy()
         # Separate out embeddings and probabilities into their own files
-        prob = df_copy[["id", "prob", "gold"]]
-        emb = df_copy[["id", "emb"]]
-        ignore_cols = ["emb", "prob", "gold", "split_id"]
-        other_cols = [i for i in df_copy.get_column_names() if i not in ignore_cols]
+        prob_cols = cls._get_prob_cols()
+        prob = df_copy[prob_cols]
+
+        if prob_only:  # In this case, we don't care about the other columns
+            emb_cols = ["id"]
+            other_cols = ["id"]
+        else:
+            emb_cols = ["id", "emb"]
+            ignore_cols = ["emb", "split_id"] + prob_cols
+            other_cols = [i for i in df_copy.get_column_names() if i not in ignore_cols]
+            other_cols += ["id"]
+
+        emb = df_copy[emb_cols]
         data_df = df_copy[other_cols]
         return prob, emb, data_df
 
+    @classmethod
+    def _get_prob_cols(cls) -> List[str]:
+        return ["id", "prob", "gold"]
+
     @classmethod
     def validate_labels(cls) -> None:
         assert cls.logger_config.labels, (
